@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0042';
+our $VERSION = '0.0043';
 
 use Moo;
 use strictures 2;
@@ -112,6 +112,7 @@ sub recall_setting {
     { id => $id },
   )->expand(json => 'settings')->hash;
   my $setting = $result->{settings};
+  $setting->{id} = $id;
   $setting->{name} = $result->{name};
   return $setting;
 }
@@ -136,9 +137,10 @@ sub search_settings {
   my $results = $self->_sqlite->query($sql);
   my @settings;
   while (my $next = $results->hash) {
-    push @settings, { $next->{id} => from_json($next->{settings}) };
-    # add the setting name to the settings data so we can use it in the templates
-    $settings[-1]->{ $next->{id} }{name} = $next->{name};
+    my $set = from_json($next->{settings});
+    $set->{id} = $next->{id};
+    $set->{name} = $next->{name};
+    push @settings, $set;
   }
   return \@settings;
 }
@@ -152,9 +154,10 @@ sub recall_all {
   my $results = $self->_sqlite->query($sql);
   my @settings;
   while (my $next = $results->hash) {
-    push @settings, { $next->{id} => from_json($next->{settings}) };
-    # add the setting name to the settings data
-    $settings[-1]->{ $next->{id} }{name} = $next->{name};
+    my $set = from_json($next->{settings});
+    $set->{id} = $next->{id};
+    $set->{name} = $next->{name};
+    push @settings, $set;
   }
   return \@settings;
 }
@@ -286,7 +289,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0042
+version 0.0043
 
 =head1 SYNOPSIS
 
@@ -298,23 +301,6 @@ version 0.0042
 
   my $name = 'My favorite setting';
 
-  my %spec = ( # default initial model specification
-    order      => [qw(group parameter control group_to param_to bottom top value unit is_default)],
-    group      => [],
-    parameter  => {},
-    control    => [qw(knob switch slider patch)],
-    group_to   => [],
-    param_to   => [],
-    bottom     => [qw(off 0 1 7AM 20)],
-    top        => [qw(on 3 4 6 7 5PM 20_000 100%)],
-    value      => [],
-    unit       => [qw(Hz o'clock)],
-    is_default => [0, 1],
-  );
-  my $spec_id = $synth->make_spec(%spec);
-  my $specs = $synth->recall_spec(id => $spec_id);
-  $synth->remove_spec;
-
   my $id1 = $synth->make_setting(name => $name, group => 'filter', etc => '...');
   my $id2 = $synth->make_setting(name => $name, group => 'sequencer', etc => '...');
 
@@ -336,6 +322,23 @@ version 0.0042
   my $names = $synth->recall_names;
   # [ 'My favorite setting' ]
 
+  my %spec = ( # default initial model specification
+    order      => [qw(group parameter control group_to param_to bottom top value unit is_default)],
+    group      => [],
+    parameter  => {},
+    control    => [qw(knob switch slider patch)],
+    group_to   => [],
+    param_to   => [],
+    bottom     => [qw(off 0 1 7AM 20)],
+    top        => [qw(on 3 4 6 7 5PM 20_000 100%)],
+    value      => [],
+    unit       => [qw(Hz o'clock)],
+    is_default => [0, 1],
+  );
+  my $spec_id = $synth->make_spec(%spec);
+  my $specs = $synth->recall_spec(id => $spec_id);
+  $synth->remove_spec;
+
   $synth->remove_setting(id => $id1);
 
   $synth->remove_settings(name => $name);
@@ -516,7 +519,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by Gene Boggs.
+This software is Copyright (c) 2023-2024 by Gene Boggs.
 
 This is free software, licensed under:
 
